.. _signal_analysis:

Signal Analysis Module
======================

.. automodule:: eyetrace.signal_analysis
   :members:
   :undoc-members:
   :show-inheritance:

This module provides advanced signal processing tools for physiological time
series, including spectral analysis, entropy measures, fractal analysis,
memory estimation, synchronization, and signal quality assessment.

.. toctree::
   :maxdepth: 1
   :caption: Submodules

   signal_analysis.fourier
   signal_analysis.entropy
   signal_analysis.hurst
   signal_analysis.lempel_ziv
   signal_analysis.higuchi
   signal_analysis.mutual_info
   signal_analysis.snr
   signal_analysis.trend
   signal_analysis.kss